/*
  Axis.cpp - Library for controlling an axis that is powered by a servo
*/

#include <Arduino.h>
#include <limits.h>
#include  <Servo.h>
#include "Axis.h"
Servo servo;

/*
   the min and max angle are class constants
   the pin is where the servo is connected
*/
Axis::Axis(int pin, int AXIS_MIN_ANGLE, int AXIS_MAX_ANGLE, int AXIS_BASE_ANGLE): MIN_ANGLE(AXIS_MIN_ANGLE), MAX_ANGLE(AXIS_MAX_ANGLE)
{
  servo.attach(pin);
  // set the axis to 90 degrees relative to the driving direction
  currentAngle = AXIS_BASE_ANGLE;
  servo.write(currentAngle);
}


/*
   sets the axis to the given angle, updates the variable currentAngle and returns the angle to whicj the axis was set
   return INT_MAX if the desired angle isn't between the smallest and the biggest possibe value
*/
int Axis::setAngle(int angle)
{
  if (angle < MIN_ANGLE || angle > MAX_ANGLE)
  {
    angle = INT_MAX;
    Serial.begin(9600);
    Serial.println("ERROR input angle out of bounds. Value is: " + String(angle));
  }
  else
  {
    currentAngle = angle;
    servo.write(angle);
  }
  return angle;

}

// returns the current Angle of the axis
int Axis::getAngle()
{
  return currentAngle;
}


