/*
  Sensor.cpp - Library for reading measurements from an SRF05 ultrasonic sensor
*/

#include "Arduino.h"
#include "Sensor.h"

// the trig pin and the echo pin are constants
Sensor::Sensor(int SENSOR_TRIG_PIN, int SENSOR_ECHO_PIN): TRIG_PIN(SENSOR_TRIG_PIN), ECHO_PIN(SENSOR_ECHO_PIN)
{
  pinMode(TRIG_PIN, OUTPUT); // Sets the trig pin as an Output
  pinMode(ECHO_PIN, INPUT); // Sets the echo pin as an Input
  // Clears the trig pin
  digitalWrite(TRIG_PIN, LOW);
  delayMicroseconds(2);
}

/*
   measures the distance between the sensor and an object
   amountOfMeasures specifies how many measures are used to create an average. interval (microseconds) specifies the interval after changing the state of the trig pin.
   recommended defaults: amountOfMeasures=2 interval = 10
*/
int Sensor::getDistance(int amountOfMeasures, int interval)
{
  float durationSum = 0;
  for (int i = 0; i < amountOfMeasures; i++)
  {
    // Sets the trigPin on HIGH state for 2 micro seconds
    digitalWrite(TRIG_PIN, HIGH);
    delayMicroseconds(interval);
    digitalWrite(TRIG_PIN, LOW);
    delayMicroseconds(interval);
    // Reads the echoPin, returns the sound wave travel time in microseconds
    durationSum += (float)pulseIn(ECHO_PIN, HIGH);
    delay(interval);
  }
  float duration = durationSum / ((float)amountOfMeasures);
  return microsecondsToCentimeters(duration);
}


/*
  converts the microseconds it took for a sound wave to travel in a distance traveled in cm
  rounds the returned value to the nearest cm
*/
int Sensor::microsecondsToCentimeters(float microseconds)
{
  // sound moves at aprroximately 340 meter per second or 29 microseconds per centimeter
  // The sound wave travels to the object and back so we have to divide per 2
  float temp = (microseconds / 29) / 2;
  temp = round(temp);
  return (int)temp;
}

