/*
  Sensor.h - Library for reading measurements from an SRF05 ultrasonic sensor
*/
#ifndef Sensor_h
#define Sensor_h

#include "Arduino.h"

class Sensor
{
  public:
    Sensor(int SENSOR_TRIG_PIN, int SENSOR_ECHO_PIN);

    /*
      measures the distance between the sensor and an object
      amountOfMeasures specifies how many measures are used to create an average. interval (microseconds) specifies the interval after changing the state of the trig pin.
      recommended defaults: amountOfMeasures=2 interval = 10
    */
    int getDistance(int amountOfMeasures, int interval);


  private:
    /*
      converts the microseconds it took for a sound wave to travel in a distance traveled in cm
      rounds the returned value to the nearest cm
    */
    int microsecondsToCentimeters(float microseconds);

    int const TRIG_PIN;
    int const ECHO_PIN;
};

#endif
