/*
  Steeper.cpp - Library for controlling a stepper
*/

#include "Arduino.h"
#include "Steeper.h"

/*
  dir pin and steep pin are pins of the driver
  forward determines wether the direction of rotation is forwards or backwards (in relation to the robot)
*/
Steeper::Steeper(int dirPin, int steepPin, bool forward)
{
  _dirPin = dirPin;
  _steepPin = steepPin;
  pinMode(_dirPin, OUTPUT);
  pinMode(_steepPin, OUTPUT);

  _steepSpeed = 12000; // arbitrary value for initiation
  _forward = forward;
  if (_forward)
  {
    digitalWrite(_dirPin, HIGH);
  }
  else
  {
    digitalWrite(_dirPin, LOW);
  }
}

/*
   makes one step
*/
void Steeper::steep()
{
  digitalWrite(_steepPin, HIGH);
  delayMicroseconds(_steepSpeed / 2);
  digitalWrite(_steepPin, LOW);
  delayMicroseconds(_steepSpeed / 2);
}

/*
   makes one step
   steepSpeed specifies the speed of the step without changing the default speed
*/
void Steeper::steep(unsigned int steepSpeed)
{
  digitalWrite(_steepPin, HIGH);
  delayMicroseconds(steepSpeed / 2);
  digitalWrite(_steepPin, LOW);
  delayMicroseconds(steepSpeed / 2);
}

/*
   sets the speed with which a step is made
*/
void Steeper::setSteepSpeed(unsigned int steepSpeed)
{
  _steepSpeed = steepSpeed;
}

/*
  sets the direction of the Stepper
*/
void Steeper::setDirection(bool forward)
{
  if (forward)
  {
    digitalWrite(_dirPin, HIGH);
  }
  else
  {
    digitalWrite(_dirPin, LOW);
  }
}



