#include <Servo.h>
#include "Steeper.h"
#include "Axis.h"
#include "Sensor.h"
//#define DEBUG

// Pins for the steppers. R stands for right and L for left
int RDIR_PIN = A3;
int RSTEP_PIN = A2;
int LDIR_PIN = A5;
int LSTEP_PIN = A4;

// pin for the servo of the axis
int AXIS_PIN = 12;

// trig and echo pins for the sensors
// F stands for front, B for back, R for right
int TRIG_PIN_F  = 11;
int ECHO_PIN_F  = 10;
int TRIG_PIN_RF = 9;
int ECHO_PIN_RF = 8;
int TRIG_PIN_RB = 7;
int ECHO_PIN_RB = 6;
int TRIG_PIN_B  = 5;
int ECHO_PIN_B  = 4;

// change to the radius in mm of the wheels you use
float WHEELRADIUS = 34;
// steps per rotation of the steppers you use
int const SPR = 400;

bool forward = true;
Steeper steeper1(RDIR_PIN, RSTEP_PIN, forward);
Steeper steeper2(LDIR_PIN, LSTEP_PIN, forward);

// default angle that makes your robot drive in straight line
int AXIS_BASE_ANGLE = 84;
// smallest angle that your axis can attain
int AXIS_MIN_ANGLE = 0;
// biggest angle that your axis can attain
int AXIS_MAX_ANGLE = 200;
Axis *axis;

void setup() {
#ifdef DEBUG
  Serial.begin(9600);
  Serial.println("DEBUG MODE");
#endif
  axis = new Axis(AXIS_PIN, AXIS_MIN_ANGLE, AXIS_MAX_ANGLE, AXIS_BASE_ANGLE);
  Serial.begin(9600);
  steeper1.setSteepSpeed(13000);
  steeper2.setSteepSpeed(13000);
}

//
Sensor sensorF(TRIG_PIN_F, ECHO_PIN_F);
Sensor sensorRF(TRIG_PIN_RF, ECHO_PIN_RF);
Sensor sensorRB(TRIG_PIN_RB, ECHO_PIN_RB);
Sensor sensorB(TRIG_PIN_B, ECHO_PIN_B);


float spaceLength = 0;
bool stop = false;
void loop() {
  // put your main code here, to run repeatedly:



}


// demonstrate the detection of an incoming collision at the front and at the back
// using the sensors by driving until an incoming collision is detected and then changing the direction
void demonstrateCollisionDetection()
{
  int distanceB = sensorB.getDistance(2, 10);
  while (distanceB > 5)
  {
    steeper1.setDirection(false);
    steeper2.setDirection(false);
    drive(213.628 / 10);
    distanceB = sensorB.getDistance(2, 10);
  }
  int distanceF = sensorF.getDistance(2, 10);
  while (distanceF > 5)
  {
    steeper1.setDirection(true);
    steeper2.setDirection(true);
    drive(213.628 / 10);
    distanceF = sensorF.getDistance(2, 10);
  }
}


// detects a parking space that is long enough and deep enough.
// positions the robot so that it is parallel to the parking space and with the back end of the robot aligned with the front end of the parking space
void demonstrateParkingSpaceDetection()
{
  if (!stop)
  {
    drive(10);
    while (sensorRF.getDistance(1, 10) > 40)
    {
      drive(10.68141);
      spaceLength += 10.68141;
      if ( sensorRB.getDistance(1, 10) > 40)
      {
        spaceLength = 0;
        delay(3000);
        while ( sensorRB.getDistance(1, 10 ) > 40 )
        {
          drive(10.68141);
          spaceLength += 10.68141;
        }
        Serial.println("STOP");
        Serial.print( String(sensorRB.getDistance(1, 10 )) + " \n\n");
      }
    }
    if (spaceLength > 20)
    {
      Serial.println(spaceLength + 60);
      stop = true;
      drive(60);
    }
  }
}

void drive(float distance) // distance in mm
{
  float steps = (distance * SPR) / (TWO_PI * WHEELRADIUS);
  for (int i = 0; i < steps; i++)
  {
    steeper1.steep();
    steeper2.steep();
  }
}

